import { Component, EventEmitter, Input, Output, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'comp-star-rating',
  standalone: true,
  imports: [CommonModule, FormsModule],
  template: `
    <div class="star-rating">
      <span 
        *ngFor="let star of stars; let i = index" 
        (click)="rate(i + 1)"
        [class.active]="(i + 1) <= currentRating"
        class="star"
      >
        ★
      </span>
    </div>
  `,
  styles: [`
    .star-rating {
      font-size: 24px;
      cursor: pointer;
    }
    .star {
      font-size: 2rem;
      color: #ccc;
    }
    .star.active {
      color: gold;
    }
    .star:hover {
      color: orange;
    }
  `]
})
export class CompStarRatingComponent implements OnInit {
  @Input() star: number = 0;
  @Output() onStarChange = new EventEmitter<number>();

  stars = [1, 2, 3, 4, 5];
  currentRating = 0;

  ngOnInit(): void {
    if (this.star > 0) {
      this.currentRating = this.star;
    }
  }

  rate(rating: number): void {
    if (rating === this.currentRating) {
      this.currentRating = 0;
    } else {
      this.currentRating = rating;
    }
    this.onStarChange.emit(this.currentRating);
  }
}