import { CommonModule } from '@angular/common';
import { Component, ElementRef, ViewChild, AfterViewInit, OnInit } from '@angular/core';
import * as echarts from 'echarts';

@Component({
  selector: 'app-ai-assistant',
  templateUrl: './ai-assistant.component.html',
  styleUrls: ['./ai-assistant.component.scss'],
  imports:[
    CommonModule
  ],
  standalone: true
})
export class AiAssistantComponent implements OnInit, AfterViewInit {
  @ViewChild('healthChart') healthChartElement!: ElementRef;
  @ViewChild('chatMessages') chatMessagesElement!: ElementRef;
  @ViewChild('chatInput') chatInputElement!: ElementRef;
  
  notificationMessage = '操作成功！';
  notificationType = 'success';
  showNotification = false;
  
  messages = [
    {
      role: 'ai',
      content: '您好！我是您的设备诊断助手。我可以帮助您分析设备振动数据、识别潜在问题并提供维护建议。请问今天有什么需要我协助的吗？',
      time: '2025-06-30 09:15:22',
      actions: [
        { icon: 'copy', text: '复制' },
        { icon: 'share', text: '分享' },
        { icon: 'thumbs-up', text: '有用' }
      ]
    },
    {
      role: 'user',
      content: '请帮我分析CNC-001设备昨天上午10:30的振动异常数据。另外，预测一下设备未来一周的健康状况。',
      time: '2025-06-30 09:16:45'
    },
    {
      role: 'ai',
      content: `
        <p>好的，正在分析CNC-001设备数据...</p>
        <p>📊 <strong>振动异常分析结果：</strong></p>
        <ul style="padding-left: 20px; margin: 10px 0;">
          <li>检测到高频振动峰值达到9.2mm，超过危险阈值</li>
          <li>异常持续时间：28分钟（10:32-11:00）</li>
          <li>主要频率：1250Hz，疑似轴承磨损特征频率</li>
          <li>与历史数据对比：异常值比上周同期高42%</li>
        </ul>
        <p>🔮 <strong>未来一周健康预测：</strong></p>
        <div class="ai-chart-container" #healthChart></div>
        <p>🛠️ <strong>维护建议：</strong></p>
        <ol style="padding-left: 20px; margin: 10px 0;">
          <li>立即检查主轴轴承状态</li>
          <li>校准X轴传感器，确保数据准确性</li>
          <li>优化进给速度参数，减少振动源</li>
          <li>建议72小时内安排预防性维护</li>
        </ol>
        <p>需要我生成详细诊断报告吗？</p>
      `,
      time: '2025-06-30 09:17:22',
      actions: [
        { icon: 'file-pdf', text: '生成报告' },
        { icon: 'chart-line', text: '详细分析' },
        { icon: 'tools', text: '维护计划' }
      ]
    }
  ];
  
  chatHistory = [
    { title: '主轴振动异常分析', date: '2025-06-29 14:30', active: true },
    { title: '设备健康报告', date: '2025-06-28 10:15', active: false },
    { title: '预测性维护建议', date: '2025-06-27 16:40', active: false },
    { title: 'CNC-003故障诊断', date: '2025-06-26 09:22', active: false },
    { title: '传感器校准问题', date: '2025-06-25 11:30', active: false }
  ];
  
  features = [
    { 
      icon: 'stethoscope', 
      title: '设备智能诊断', 
      desc: '基于振动数据和机器学习模型，实时分析设备健康状态，识别潜在故障并提供解决方案。',
      btnText: '开始诊断'
    },
    { 
      icon: 'chart-line', 
      title: '预测性维护分析', 
      desc: '预测设备未来健康状况和故障概率，生成最优维护计划，减少意外停机时间。',
      btnText: '运行预测'
    },
    { 
      icon: 'file-alt', 
      title: 'AI报告生成', 
      desc: '一键生成专业诊断报告，包含数据可视化、问题分析和维护建议，支持PDF导出。',
      btnText: '生成报告'
    },
    { 
      icon: 'bolt', 
      title: '快速命令', 
      desc: '常用功能快捷入口，快速执行设备诊断、数据分析和报告生成。',
      commands: [
        { icon: 'search', text: '分析当前设备' },
        { icon: 'exchange-alt', text: '对比历史数据' },
        { icon: 'file-medical', text: '生成健康报告' },
        { icon: 'cogs', text: '优化运行参数' },
        { icon: 'wifi', text: '检查传感器状态' },
        { icon: 'chart-bar', text: '查看趋势分析' }
      ]
    }
  ];

  ngOnInit() {
    // 初始化数据
  }

  ngAfterViewInit() {
    this.initHealthChart();
    this.scrollToBottom();
  }

  initHealthChart() {
    const chart = echarts.init(this.healthChartElement.nativeElement);
    const option = {
      backgroundColor: 'transparent',
      tooltip: {
        trigger: 'axis',
        backgroundColor: 'rgba(255, 255, 255, 0.95)',
        borderColor: '#e1e6ef',
        textStyle: { color: '#2d3748' },
        axisPointer: {
          type: 'line',
          lineStyle: {
            color: '#8b5cf6',
            width: 2
          }
        }
      },
      grid: {
        left: '3%',
        right: '4%',
        bottom: '3%',
        top: '10%',
        containLabel: true
      },
      xAxis: {
        type: 'category',
        data: ['今天', '明天', '第3天', '第4天', '第5天', '第6天', '第7天'],
        axisLine: { lineStyle: { color: '#e1e6ef' } },
        axisLabel: { color: '#718096' }
      },
      yAxis: {
        type: 'value',
        name: '健康分数',
        min: 0,
        max: 100,
        nameTextStyle: { color: '#718096' },
        axisLine: { lineStyle: { color: '#e1e6ef' } },
        axisLabel: { 
          color: '#718096',
          formatter: '{value}'
        },
        splitLine: { lineStyle: { color: '#f1f5f9' } }
      },
      series: [
        {
          name: '健康分数',
          type: 'line',
          data: [86, 82, 78, 75, 70, 68, 65],
          smooth: true,
          lineStyle: { 
            color: '#10b981',
            width: 3
          },
          symbol: 'circle',
          symbolSize: 8,
          itemStyle: { color: '#10b981' },
          areaStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0, color: 'rgba(16, 185, 129, 0.2)' },
              { offset: 1, color: 'rgba(16, 185, 129, 0.05)' }
            ])
          },
          markLine: {
            silent: true,
            lineStyle: { color: '#ef4444', width: 1, type: 'dashed' },
            data: [
              { yAxis: 70, name: '维护阈值' }
            ],
            label: {
              formatter: '维护阈值',
              position: 'end',
              color: '#ef4444'
            }
          },
          animation: true,
          animationDuration: 2000,
          animationEasing: 'cubicOut'
        }
      ]
    };
    chart.setOption(option);
  }

  sendMessage() {
    const message = this.chatInputElement.nativeElement.value.trim();
    if (!message) return;

    // 添加用户消息
    this.messages.push({
      role: 'user',
      content: message,
      time: this.getCurrentTime()
    });

    this.chatInputElement.nativeElement.value = '';
    this.scrollToBottom();

    // 添加AI思考中消息
    const thinkingMessage = {
      role: 'ai',
      content: '<div class="thinking-dots"><div class="dot"></div><div class="dot"></div><div class="dot"></div></div>',
      time: this.getCurrentTime()
    };
    this.messages.push(thinkingMessage);
    this.scrollToBottom();

    // 模拟AI回复
    setTimeout(() => {
      const responses = [
        "根据您的查询，我分析了设备数据：振动峰值在昨天10:32达到9.2mm，主要频率集中在1250Hz范围。建议检查主轴轴承状态并校准X轴传感器。",
        "数据分析完成：检测到异常振动模式与轴承磨损特征相符。预测未来72小时内健康指数将下降8%，建议尽快安排维护。",
        "已完成设备健康评估。当前健康评分78分（满分100），预测未来一周将下降至65分。维护建议已生成，需要查看详细报告吗？",
        "已生成诊断报告：1. 主轴轴承磨损（中度）2. 传感器校准偏差（±0.15mm）3. 冷却系统效率下降12%。需要我制定维护计划吗？"
      ];
      
      this.messages.pop(); // 移除思考中消息
      
      this.messages.push({
        role: 'ai',
        content: responses[Math.floor(Math.random() * responses.length)],
        time: this.getCurrentTime(),
        actions: [
          { icon: 'copy', text: '复制' },
          { icon: 'share', text: '分享' },
          { icon: 'thumbs-up', text: '有用' }
        ]
      });
      
      this.scrollToBottom();
    }, 2000);
  }

  onKeyPress(event: KeyboardEvent) {
    if (event.key === 'Enter' && !event.shiftKey) {
      event.preventDefault();
      this.sendMessage();
    }
  }

  newChat() {
    this.messages = [{
      role: 'ai',
      content: '您好！我是您的设备诊断助手。请问今天有什么需要我协助的吗？',
      time: this.getCurrentTime(),
      actions: [
        { icon: 'copy', text: '复制' },
        { icon: 'share', text: '分享' },
        { icon: 'thumbs-up', text: '有用' }
      ]
    }];
    
    this.displayNotification('新对话已创建', 'success');
  }
  displayNotification(arg0: string, arg1: string) {
    throw new Error('Method not implemented.');
  }

  activateHistory(index: number) {
    this.chatHistory.forEach(item => item.active = false);
    this.chatHistory[index].active = true;
  }

  runFeature(feature: string) {
    const messages = {
      diagnose: '设备诊断已启动...',
      predict: '预测分析中...',
      report: '报告生成中...'
    };
    
    this.displayNotification(messages[feature as keyof typeof messages] || '功能执行中...', 'info');
    
    setTimeout(() => {
      let content = '';
      
      switch(feature) {
        case 'diagnose':
          content = "设备诊断已完成：<br>✅ CNC-001: 主轴轴承中度磨损（建议72小时内更换）<br>✅ CNC-003: 传感器校准正常<br>⚠️ CNC-005: 冷却系统效率下降15%";
          break;
        case 'predict':
          content = "预测性维护分析结果：<br>📅 最佳维护时间：2025-07-02 上午<br>🔧 预计维护时长：2.5小时<br>💡 维护后健康提升：+25分<br>📉 避免停机损失：约¥8,500";
          break;
        case 'report':
          content = "诊断报告已生成！包含以下内容：<br>1. 设备健康评分（86/100）<br>2. 异常振动分析<br>3. 预测性维护计划<br>4. 备件更换建议<br>需要导出PDF版本吗？";
          break;
      }
      
      this.messages.push({
        role: 'ai',
        content,
        time: this.getCurrentTime()
      });
      
      this.scrollToBottom();
    }, 1800);
  }

  runCommand(command: string) {
    let message = "";
    
    switch(command) {
      case 'analyze':
        message = "请分析当前设备CNC-001的振动数据";
        break;
      case 'compare':
        message = "对比CNC-001上周同期的振动数据";
        break;
      case 'report':
        message = "生成CNC-001的健康诊断报告";
        break;
      case 'optimize':
        message = "优化CNC-001的运行参数以减少振动";
        break;
      case 'sensor':
        message = "检查所有传感器的状态和校准情况";
        break;
      case 'trend':
        message = "展示过去30天的振动趋势分析";
        break;
    }
    
    this.messages.push({
      role: 'user',
      content: message,
      time: this.getCurrentTime()
    });
    
    this.scrollToBottom();
    
    // 模拟AI回复
    setTimeout(() => {
      const responses = {
        analyze: "CNC-001分析完成：检测到高频振动异常，峰值9.2mm（危险阈值9.0mm），建议立即检查主轴轴承。",
        compare: "数据对比结果：当前振幅比上周高42%，异常持续时间增加28分钟。频率分布显示轴承磨损特征更加明显。",
        report: "设备健康报告已生成：<br>健康评分：78/100<br>主要问题：轴承磨损（代码F-203）<br>维护建议：72小时内更换轴承",
        optimize: "参数优化建议：<br>1. 降低进给速度15%<br>2. 调整主轴转速至1800rpm<br>3. 增加冷却液流量20%<br>预计可减少振动幅度30%。",
        sensor: "传感器状态检查：<br>✅ 振动传感器：正常<br>⚠️ 温度传感器：需要校准（偏差±2.1℃）<br>✅ 转速传感器：正常",
        trend: "过去30天振动趋势：<br>📈 平均振幅增长：0.15mm/天<br>⚠️ 超标天数：8天<br>📉 健康评分下降：22分"
      };
      
      this.messages.push({
        role: 'ai',
        content: responses[command as keyof typeof responses] || '命令执行完成',
        time: this.getCurrentTime()
      });
      
      this.scrollToBottom();
    }, 1500);
  }

  isNotificationVisible

(message: string, type: 'success' | 'error' | 'warning' | 'info' = 'success') {
    this.notificationMessage = message;
    this.notificationType = type;
    this.showNotification = true;
    
    setTimeout(() => {
      this.showNotification = false;
    }, 3000);
  }

  scrollToBottom() {
    setTimeout(() => {
      if (this.chatMessagesElement) {
        this.chatMessagesElement.nativeElement.scrollTop = 
          this.chatMessagesElement.nativeElement.scrollHeight;
      }
    }, 100);
  }

  getCurrentTime() {
    const now = new Date();
    return now.toLocaleString('zh-CN', {
      year: 'numeric',
      month: '2-digit',
      day: '2-digit',
      hour: '2-digit',
      minute: '2-digit',
      second: '2-digit'
    });
  }
}